@@ -14,7 +14,7 @@ from highdicom.enum import CoordinateSystemNames
 from highdicom.frame import encode_frame
 from highdicom.pm.content import RealWorldValueMapping
 from highdicom.pm.content import DimensionIndexSequence
-from highdicom.valuerep import check_person_name
+from highdicom.valuerep import check_person_name, _check_code_string
 from pydicom import Dataset
 from pydicom.uid import (
     UID,
@@ -63,6 +63,7 @@ class ParametricMap(SOPClass):
         pixel_measures: Optional[PixelMeasuresSequence] = None,
         plane_orientation: Optional[PlaneOrientationSequence] = None,
         plane_positions: Optional[Sequence[PlanePositionSequence]] = None,
+        content_label: Optional[str] = None,
         **kwargs,
     ):
         """
@@ -181,6 +182,8 @@ class ParametricMap(SOPClass):
             number of frames in `source_images` (in case of multi-frame source
             images) or the number of `source_images` (in case of single-frame
             source images).
+        content_label: Union[str, None], optional
+            Content label
         **kwargs: Any, optional
             Additional keyword arguments that will be passed to the constructor
             of `highdicom.base.SOPClass`
@@ -356,16 +359,18 @@ class ParametricMap(SOPClass):
             self.RecognizableVisualFeatures = 'YES'
         else:
             self.RecognizableVisualFeatures = 'NO'
-        self.ContentLabel = 'ISO_IR 192'  # UTF-8
+
+        if content_label is not None:
+            _check_code_string(content_label)
+            self.ContentLabel = content_label
+        else:
+            self.ContentLabel = 'MAP'
         self.ContentDescription = content_description
         if content_creator_name is not None:
             check_person_name(content_creator_name)
         self.ContentCreatorName = content_creator_name
         self.PresentationLUTShape = 'IDENTITY'
 
-        # TODO: check that physical dimensions of the image match those of the
-        # source image
-
         self.DimensionIndexSequence = DimensionIndexSequence(coordinate_system)
         dimension_organization = Dataset()
         dimension_organization.DimensionOrganizationUID = (
@@ -429,6 +434,8 @@ class ParametricMap(SOPClass):
         self.Rows = pixel_array.shape[1]
         self.Columns = pixel_array.shape[2]
 
+        # TODO: tiled image with Total Pixel Matrix Rows/Columns
+
         if len(real_world_value_mappings) != pixel_array.shape[3]:
             raise ValueError(
                 'Number of RealWorldValueMapping items provided via '
@@ -436,22 +443,40 @@ class ParametricMap(SOPClass):
                 'last dimension of "pixel_array" argument.'
             )
 
-        if plane_positions is None:
-            if is_multiframe:
-                plane_positions = \
-                    self.DimensionIndexSequence.get_plane_positions_of_image(
-                        self._source_images[0]
-                    )
+        if is_multiframe:
+            source_plane_positions = \
+                self.DimensionIndexSequence.get_plane_positions_of_image(
+                    self._source_images[0]
+                )
+            if coordinate_system == CoordinateSystemNames.SLIDE:
+                source_plane_orientation = PlaneOrientationSequence(
+                    coordinate_system=coordinate_system,
+                    image_orientation=[
+                        float(v) for v in src_img.ImageOrientationSlide
+                    ],
+                )
             else:
-                plane_positions = \
-                    self.DimensionIndexSequence.get_plane_positions_of_series(
-                        self._source_images
-                    )
-            if len(plane_positions) != pixel_array.shape[0]:
+                src_sfg = src_img.SharedFunctionalGroupsSequence[0]
+                source_plane_orientation = src_sfg.PlaneOrientationSequence
+        else:
+            source_plane_positions = \
+                self.DimensionIndexSequence.get_plane_positions_of_series(
+                    self._source_images
+                )
+            source_plane_orientation = PlaneOrientationSequence(
+                coordinate_system=coordinate_system,
+                image_orientation=[
+                    float(v) for v in src_img.ImageOrientationPatient
+                ],
+            )
+
+        if plane_positions is None:
+            if pixel_array.shape[0] != len(source_plane_positions):
                 raise ValueError(
                     'Number of plane positions in source image(s) does not '
                     'match size of first dimension of "pixel_array" argument.'
                 )
+            plane_positions = source_plane_positions
         else:
             if len(plane_positions) != pixel_array.shape[0]:
                 raise ValueError(
@@ -460,6 +485,63 @@ class ParametricMap(SOPClass):
                     'first dimension of "pixel_array" argument.'
                 )
 
+        if plane_orientation is None:
+            plane_orientation = source_plane_orientation
+
+        are_spatial_locations_preserved = (
+            all(
+                plane_positions[i] == source_plane_positions[i]
+                for i in range(len(plane_positions))
+            ) and
+            plane_orientation == source_plane_orientation
+        )
+
+        plane_position_values, plane_sort_index = \
+            self.DimensionIndexSequence.get_index_values(plane_positions)
+
+        if coordinate_system == CoordinateSystemNames.SLIDE:
+            self.ImageOrientationSlide = \
+                plane_orientation[0].ImageOrientationSlide
+            if are_spatial_locations_preserved:
+                self.TotalPixelMatrixOriginSequence = \
+                    source_images[0].TotalPixelMatrixOriginSequence
+                self.TotalPixelMatrixRows = \
+                    source_images[0].TotalPixelMatrixRows
+                self.TotalPixelMatrixColumns = \
+                    source_images[0].TotalPixelMatrixColumns
+            else:
+                row_index = self.DimensionIndexSequence.get_index_position(
+                    'RowPositionInTotalImagePixelMatrix'
+                )
+                row_offsets = plane_position_values[:, row_index]
+                col_index = self.DimensionIndexSequence.get_index_position(
+                    'ColumnPositionInTotalImagePixelMatrix'
+                )
+                col_offsets = plane_position_values[:, col_index]
+                frame_indices = np.lexsort([row_offsets, col_offsets])
+                first_frame_index = frame_indices[0]
+                last_frame_index = frame_indices[-1]
+                x_index = self.DimensionIndexSequence.get_index_position(
+                    'XOffsetInSlideCoordinateSystem'
+                )
+                x_offset = plane_position_values[first_frame_index, x_index]
+                y_index = self.DimensionIndexSequence.get_index_position(
+                    'YOffsetInSlideCoordinateSystem'
+                )
+                y_offset = plane_position_values[first_frame_index, y_index]
+                origin_item = Dataset()
+                origin_item.XOffsetInSlideCoordinateSystem = x_offset
+                origin_item.YOffsetInSlideCoordinateSystem = y_offset
+                self.TotalPixelMatrixOriginSequence = [origin_item]
+                self.TotalPixelMatrixRows = (
+                    plane_position_values[last_frame_index, row_index] +
+                    self.Rows
+                )
+                self.TotalPixelMatrixColumns = (
+                    plane_position_values[last_frame_index, col_index] +
+                    self.Columns
+                )
+
         # Multi-Frame Functional Groups and Multi-Frame Dimensions
         if pixel_measures is None:
             if is_multiframe:
@@ -474,27 +556,6 @@ class ParametricMap(SOPClass):
                     ),
                 )
 
-        if is_multiframe:
-            if coordinate_system == CoordinateSystemNames.SLIDE:
-                source_plane_orientation = PlaneOrientationSequence(
-                    coordinate_system=coordinate_system,
-                    image_orientation=[
-                        float(v) for v in src_img.ImageOrientationSlide
-                    ],
-                )
-            else:
-                src_sfg = src_img.SharedFunctionalGroupsSequence[0]
-                source_plane_orientation = src_sfg.PlaneOrientationSequence
-        else:
-            source_plane_orientation = PlaneOrientationSequence(
-                coordinate_system=coordinate_system,
-                image_orientation=[
-                    float(v) for v in src_img.ImageOrientationPatient
-                ],
-            )
-        if plane_orientation is None:
-            plane_orientation = source_plane_orientation
-
         sffg_item.PixelMeasuresSequence = pixel_measures
         sffg_item.PlaneOrientationSequence = plane_orientation
 
@@ -528,7 +589,7 @@ class ParametricMap(SOPClass):
         # TODO: put Real World Value Mapping Sequence into shared
         self.SharedFunctionalGroupsSequence = [sffg_item]
 
-        # Get the correct attribute for this Instance's pixel data
+        # Get the correct pixel data attribute
         pixel_data_type, pixel_data_attr = self._get_pixel_data_type_and_attr(
             pixel_array
         )
